﻿using System;
using System.Text;

using DevExpress.XtraEditors;
using DevExpress.XtraMap;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : XtraForm
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 빙 맵 키
        /// </summary>
        private string bingKey = "INPUT YOUR BING KEY";

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            this.bingMapDataProvider.BingKey    = this.bingKey;
            this.bingSearchDataProvider.BingKey = this.bingKey;

            this.bingSearchDataProvider.SearchCompleted += bingSearchDataProvider_SearchCompleted;
            this.informationLayer.DataRequestCompleted  += informationLayer_DataRequestCompleted;
            this.searchButton.Click                     += searchButton_Click;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 조회 버튼 클릭시 처리하기 - searchButton_Click(sender, e)

        /// <summary>
        /// 조회 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void searchButton_Click(object sender, EventArgs e)
        {
            this.bingSearchDataProvider.Search(this.keywordTextEdit.Text);
        }

        #endregion
        #region 빙 검색 데이터 공급자 검색 완료시 처리하기 - bingSearchDataProvider_SearchCompleted(sender, e)

        /// <summary>
        /// 빙 검색 데이터 공급자 검색 완료시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void bingSearchDataProvider_SearchCompleted(object sender, BingSearchCompletedEventArgs e)
        {
            if (e.Cancelled)
            {
                return;
            }

            if (e.RequestResult.ResultCode != RequestResultCode.Success)
            {
                this.resultMemoEdit.Text = "The Bing Search service does not work for this location.";

                return;
            }

            StringBuilder stringBuilder = new StringBuilder("");

            int count = 1;

            foreach (BingLocationInformation information in e.RequestResult.SearchResults)
            {
                stringBuilder.AppendFormat("Result {0}", count);
                stringBuilder.AppendLine();
                stringBuilder.AppendFormat("Name : {0}", information.DisplayName);
                stringBuilder.AppendLine();
                stringBuilder.AppendFormat("Address : {0}", information.Address.FormattedAddress);
                stringBuilder.AppendLine();
                stringBuilder.AppendFormat("Confidence level : {0}", information.Confidence);
                stringBuilder.AppendLine();
                stringBuilder.AppendFormat("Geographic coordinates : {0}", information.Location);
                stringBuilder.AppendLine();
                stringBuilder.AppendFormat("Match code : {0}", information.MatchCode);
                stringBuilder.AppendLine();
                stringBuilder.AppendLine("--------------------------------------------------");

                count++;
            }

            this.resultMemoEdit.Text = stringBuilder.ToString();
        }

        #endregion
        #region 정보 레이어 데이터 요청 완료시 처리하기 - informationLayer_DataRequestCompleted(sender, e)

        /// <summary>
        /// 정보 레이어 데이터 요청 완료시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void informationLayer_DataRequestCompleted(object sender, RequestCompletedEventArgs e)
        {
            this.mapControl.ZoomToFitLayerItems(0.4);
        }

        #endregion
    }
}